package de.wwwu.awolf.presenter.data.generator;

import de.wwwu.awolf.model.Line;

import java.security.SecureRandom;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Implementierung verschiedener Algorithmen zur Berechnung von Ausgleichsgeraden.
 *
 * @Author: Armin Wolf
 * @Email: a_wolf28@uni-muenster.de
 * @Date: 01.08.2017.
 */
public class DatasetGenerator {

    private static SecureRandom random;

    /**
     * Konstruktor
     */
    private DatasetGenerator() {
        random = new SecureRandom();
    }


    /**
     * Generieren eines Datensatzes des typen: Gerade. Die Geraden werden in eine
     * übergebene Liste hinzugefügt.
     *
     * @param n Größe des Datensatzes
     * @return Liste des Geraden
     */
    public static List<Line> generateDataLines(List<Line> lines, int n) {
        double m = 5d;
        double b = 0d;

        int size = 0;
        Map<Double, Double> points = new HashMap<>();

        //speichere die Koordinaten in einer HashMap, damit keine Punkte
        //entstehen deren x-Koordinate zu sehr beieinander liegt.
        while (size < n) {
            double y = random.nextGaussian();
            double signal = m * y + b;
            signal *= -1;

            if (!points.containsKey(y)) {
                points.put(y, signal);
                size++;
            }
        }

        int idx = lines.size();
        for (Double d : points.keySet()) {
            Line line = new Line(d, points.get(d));
            line.setId(idx + "");
            lines.add(line);
            idx++;
        }

        return lines;
    }

}

